@@ -57,7 +57,7 @@ def build_temp_workspace(files):
     tempdir = tempfile.mkdtemp(prefix='yamllint-tests-')
 
     for path, content in files.items():
-        path = os.path.join(tempdir, path)
+        path = os.path.join(tempdir, path).encode('utf-8')
         if not os.path.exists(os.path.dirname(path)):
             os.makedirs(os.path.dirname(path))
 
