@@ -47,16 +47,15 @@ class ModuleTestCase(unittest.TestCase):
             subprocess.check_output([PYTHON, '-m', 'yamllint'],
                                     stderr=subprocess.STDOUT)
         self.assertEqual(ctx.exception.returncode, 2)
-        self.assertRegexpMatches(ctx.exception.output.decode(),
-                                 r'^usage: yamllint')
+        self.assertRegex(ctx.exception.output.decode(), r'^usage: yamllint')
 
     def test_run_module_on_bad_dir(self):
         with self.assertRaises(subprocess.CalledProcessError) as ctx:
             subprocess.check_output([PYTHON, '-m', 'yamllint',
                                      '/does/not/exist'],
                                     stderr=subprocess.STDOUT)
-        self.assertRegexpMatches(ctx.exception.output.decode(),
-                                 r'No such file or directory')
+        self.assertRegex(ctx.exception.output.decode(),
+                         r'No such file or directory')
 
     def test_run_module_on_file(self):
         out = subprocess.check_output(
