@@ -24,6 +24,15 @@ Use this rule to control the number of spaces before and after colons (``:``).
 * ``max-spaces-after`` defines the maximal number of spaces allowed after
   colons (use ``-1`` to disable).
 
+.. rubric:: Default values (when enabled)
+
+.. code-block:: yaml
+
+ rules:
+   colons:
+     max-spaces-before: 0
+     max-spaces-after: 1
+
 .. rubric:: Examples
 
 #. With ``colons: {max-spaces-before: 0, max-spaces-after: 1}``
@@ -72,7 +81,7 @@ Use this rule to control the number of spaces before and after colons (``:``).
 
 import yaml
 
-from yamllint.rules.common import spaces_after, spaces_before, is_explicit_key
+from yamllint.rules.common import is_explicit_key, spaces_after, spaces_before
 
 
 ID = 'colons'
