@@ -30,6 +30,18 @@ This can be useful to prevent surprises from YAML parsers transforming
   ``'False'``, ``'false'``, ``'YES'``, ``'Yes'``, ``'yes'``, ``'NO'``,
   ``'No'``, ``'no'``, ``'ON'``, ``'On'``, ``'on'``, ``'OFF'``, ``'Off'``,
   ``'off'``.
+* ``check-keys`` disables verification for keys in mappings. By default,
+  ``truthy`` rule applies to both keys and values. Set this option to ``false``
+  to prevent this.
+
+.. rubric:: Default values (when enabled)
+
+.. code-block:: yaml
+
+ rules:
+   truthy:
+     allowed-values: ['true', 'false']
+     check-keys: true
 
 .. rubric:: Examples
 
@@ -92,6 +104,22 @@ This can be useful to prevent surprises from YAML parsers transforming
     - false
     - on
     - off
+
+#. With ``truthy: {check-keys: false}``
+
+   the following code snippet would **PASS**:
+   ::
+
+    yes:  1
+    on:   2
+    true: 3
+
+   the following code snippet would **FAIL**:
+   ::
+
+    yes:  Yes
+    on:   On
+    true: True
 """
 
 import yaml
@@ -109,14 +137,18 @@ TRUTHY = ['YES', 'Yes', 'yes',
 
 ID = 'truthy'
 TYPE = 'token'
-CONF = {'allowed-values': list(TRUTHY)}
-DEFAULT = {'allowed-values': ['true', 'false']}
+CONF = {'allowed-values': list(TRUTHY), 'check-keys': bool}
+DEFAULT = {'allowed-values': ['true', 'false'], 'check-keys': True}
 
 
 def check(conf, token, prev, next, nextnext, context):
     if prev and isinstance(prev, yaml.tokens.TagToken):
         return
 
+    if (not conf['check-keys'] and isinstance(prev, yaml.tokens.KeyToken) and
+            isinstance(token, yaml.tokens.ScalarToken)):
+        return
+
     if isinstance(token, yaml.tokens.ScalarToken):
         if (token.value in (set(TRUTHY) - set(conf['allowed-values'])) and
                 token.style is None):
